@@ -101,10 +101,6 @@ class RenderTagTest < Minitest::Test
     end
   end
 
-  def test_dynamically_choosen_templates_are_not_allowed
-    assert_syntax_error("{% assign name = 'snippet' %}{% render name %}")
-  end
-
   def test_rigid_parsing_errors
     with_error_modes(:lax, :strict) do
       assert_template_result(
@@ -294,6 +290,13 @@ class RenderTagTest < Minitest::Test
     )
   end
 
+  def test_render_tag_with_snippet_drop
+    assert_template_result(
+      "Hello from snippet",
+      "{% snippet my_snippet %}Hello from snippet{% endsnippet %}{% render my_snippet %}",
+    )
+  end
+
   def test_render_tag_renders_error_with_template_name
     assert_template_result(
       'Liquid error (foo line 1): standard error',
